@@ -10,8 +10,8 @@
 #' @examples
 #' height <- rnorm(100, 170, 8)
 #' rel_dis(height)
-rel_dis <- function(x)
-{
+#' @export
+rel_dis <- function(x) {
   rd <- sd(x, na.rm = TRUE) / mean(x, na.rm = TRUE)
   rd
 }
@@ -32,8 +32,8 @@ rel_dis <- function(x)
 #' round(sd(x), 2)
 #'
 #' round(reference_range(mean(x), sd(x)), 2)
-reference_range <- function(avg, std)
-{
+#' @export
+reference_range <- function(avg, std) {
   lower.ri <- avg - qnorm(0.975) * std
   upper.ri <- avg + qnorm(0.975) * std
   ri <- data.frame(lower.ri, upper.ri)
@@ -47,13 +47,13 @@ reference_range <- function(avg, std)
 #' @examples
 #' data(IgM, package = "ISwR")
 #' Ab <- data.frame(IgM)
-#' estat(~ IgM, data = Ab)
+#' estat(~IgM, data = Ab)
 #' geo_mean(IgM)
-geo_mean <- function(x)
-{
+#' @export
+geo_mean <- function(x) {
   positive.check <- which(x <= 0)
   if (length(positive.check) >= 1) {
-    print('Some observations are not positive')
+    print("Some observations are not positive")
   } else {
     lx <- length(x)
     geo <- exp(sum(log(x), na.rm = TRUE) / lx)
@@ -68,13 +68,13 @@ geo_mean <- function(x)
 #' @examples
 #' data(IgM, package = "ISwR")
 #' Ab <- data.frame(IgM)
-#' estat(~ IgM, data = Ab)
+#' estat(~IgM, data = Ab)
 #' harm_mean(IgM)
-harm_mean <- function(x)
-{
+#' @export
+harm_mean <- function(x) {
   zero.check <- which(x == 0)
   if (length(zero.check) >= 1) {
-    print('Some observations are equal to zero')
+    print("Some observations are equal to zero")
   } else {
     lx <- length(x)
     inv <- sum(1 / x, na.rm = TRUE)
@@ -98,28 +98,31 @@ harm_mean <- function(x)
 #' bst(IgM, "median")
 #'
 #' bst(IgM, "gmean")
-bst <- function (x, stat = "mean", n = 1000, CI = 95, digits = 2)
-{
+#' @export
+bst <- function(x, stat = "mean", n = 1000, CI = 95, digits = 2) {
   xmeans <- numeric(n)
   if (stat == "median") {
-    for (i in 1:n) xmeans[i] <- median(sample(x, replace = TRUE),
-                                       na.rm = TRUE)
+    for (i in 1:n) {
+      xmeans[i] <- median(sample(x, replace = TRUE),
+        na.rm = TRUE
+      )
+    }
     estimate <- median(x, na.rm = TRUE)
-  }
-  else if (stat == "gmean") {
+  } else if (stat == "gmean") {
     for (i in 1:n) xmeans[i] <- geo_mean(sample(x, replace = TRUE))
     estimate <- geo_mean(x)
-  }
-  else if (stat == "mean") {
-    for (i in 1:n) xmeans[i] <- mean(sample(x, replace = TRUE),
-                                     na.rm = TRUE)
+  } else if (stat == "mean") {
+    for (i in 1:n) {
+      xmeans[i] <- mean(sample(x, replace = TRUE),
+        na.rm = TRUE
+      )
+    }
     estimate <- mean(x, na.rm = TRUE)
-  }
-  else {
+  } else {
     stop("Statistic not available")
   }
-  alpha <- 1 - (CI/100)
-  tail <- alpha/2
+  alpha <- 1 - (CI / 100)
+  tail <- alpha / 2
   lower <- round(quantile(xmeans, tail, na.rm = TRUE), digits = digits)
   upper <- round(quantile(xmeans, 1 - tail, na.rm = TRUE), digits = digits)
   estimate <- round(estimate, digits = digits)
@@ -136,8 +139,7 @@ bst <- function (x, stat = "mean", n = 1000, CI = 95, digits = 2)
 #' @param x a numeric variable
 #' @param data2 A data frame where \code{x} can be found.
 #' @param digits Number of digits for rounding.
-stats_quotes <- function(x, data2, digits = 2)
-{
+stats_quotes <- function(x, data2, digits = 2) {
   n <- sum(!is.na(data2[[x]]))
   x.min <- min(data2[[x]], na.rm = TRUE)
   x.max <- max(data2[[x]], na.rm = TRUE)
@@ -147,7 +149,7 @@ stats_quotes <- function(x, data2, digits = 2)
   cv <- std / avg
   res <- data.frame(n, x.min, x.max, avg, med, std, cv)
   names(res) <- c("N", "Min.", "Max.", "Mean", "Median", "SD", "CV")
-  res <- round(res, digits=digits)
+  res <- round(res, digits = digits)
   res
 }
 
@@ -161,33 +163,18 @@ stats_quotes <- function(x, data2, digits = 2)
 #' @param label A character, label to be used for the outcome (for non-labelled data).
 #' @param show.total Logical, show column with totals?
 #' @param p_val Logical, show p-values?
+#' @param pad Numerical, padding above and bellow rows.
+#' @param width Numerical, proportional width of the table.
+#' @param method An integer indicating methods for continuous variables.
+#' 1 Reports means and standard deviations.
+#' 2 Reports medians and interquartile ranges.
 #' @param ... Additional arguments passed to \code{\link[moonBook]{mytable_sub}}.
 #' @details Function \code{cross_tab} is a relatively simple wrapper to function \code{mytable} of package \code{moonBook}. Its main purpose is to construct contingency tables but it can also be used to report a table with descriptives for all variables as long as they are still stratified by the outcome. Please see examples to see how to list explanatory variables. For categorical explanatory variables, the function reports column percentages. If data is labelled with \code{sjlabelled}, the label of the outcome (dependent) variable is used to name the outcome; this name can be changed with argument \code{label}.
 #' @return A huxtable with descriptive statistics stratified by levels of the outcome.
 #' @seealso \code{\link[moonBook]{mytable}}
-#' @examples
-#' data(Oncho)
-#'
-#' ## A two by two contingency table:
-#' Oncho %>%
-#'   cross_tab(mf ~ area)
-#'
-#' ## Reporting prevalence:
-#' Oncho %>%
-#'   cross_tab(area ~ mf)
-#'
-#' ## Contingency table for both sex and area of residence:
-#' Oncho %>%
-#'   cross_tab(mf ~ sex + area, p_val = TRUE)
-#'
-#' ## Descriptive statistics for all variables in the \code{Oncho} data set except \code{id}.
-#' require(dplyr, quietly = TRUE)
-#' Oncho %>%
-#'   select(- id) %>%
-#'   cross_tab(mf ~ .)
-cross_tab <- function(object = NULL, formula = NULL, data = NULL,
-                      label = NULL, show.total = TRUE, p_val = FALSE, ...)
-{
+cross_tab <- function(object = NULL, formula = NULL, data = NULL, label = NULL,
+                      show.total = TRUE, p_val = FALSE, pad = 3, width = 0.8, method = 1, ...) {
+  .Deprecated("cross_tbl")
   if (inherits(object, "formula")) {
     formula <- object
     object <- NULL
@@ -207,32 +194,142 @@ cross_tab <- function(object = NULL, formula = NULL, data = NULL,
   nl2 <- nl + 1
   if (is.null(sjlabelled::get_label(outcome)) == FALSE & is.null(label)) {
     lab <- sjlabelled::get_label(outcome)
-  }
-  else {
+  } else {
     lab <- ifelse(is.null(label), dependent, label)
   }
-  tbl <- moonBook::mytable(formula, data = data, show.total = show.total, ...) %>%
-    moonBook::mytable2df()
-  if(p_val == TRUE) {
+  tbl <- moonBook::mytable(formula,
+    data = data, show.total = show.total,
+    method = method, ...
+  ) %>% moonBook::mytable2df()
+  if (p_val == TRUE) {
     tvl <- tbl
-  } else{
+  } else {
     tvl <- tbl %>% dplyr::select(-ncol(tbl))
   }
   names(tvl)[1] <- " "
+
   res <- tvl %>%
-    huxtable::as_hux() %>% huxtable::set_align(huxtable::everywhere, 2:nl, "right") %>%
+    huxtable::as_hux() %>%
+    huxtable::set_align(huxtable::everywhere, 2:nl, "right") %>%
     huxtable::insert_row(c(" ", lab), fill = " ") %>%
     huxtable::merge_cells(1, 2:nm) %>%
     huxtable::set_header_rows(1, TRUE) %>%
     huxtable::set_align(1:3, huxtable::everywhere, "center")
-  if(nv > 1){
-    res = res
+  if (nv > 1) {
+    res <- res
   } else {
-    res = res %>% huxtable::set_bold(4, 1)
+    res <- res %>% huxtable::set_bold(4, 1)
   }
+
+  res <- res %>%
+    huxtable::set_top_padding(pad) %>%
+    huxtable::set_bottom_padding(pad) %>%
+    huxtable::set_width(width)
+
   res
 }
 
+#' Table of descriptive statistics by categorical variable.
+#'
+#' \code{cross_tbl} is a wrapper to function  from package \code{\link[gtsummary]{tbl_summary}} that constructs tables of descriptive statistics stratified by levels of a categorical outcome.
+#' @param data A data frame where the variables in the \code{formula} can be found.
+#' @param by The quoted name of the  categorical variable (factor) used for the stratification.
+#' @param head_label Character, label to be used as head for the variable's column.
+#' @param bold Display labels in bold?
+#' @param show_total Logical, show column with totals?
+#' @param p_val Logical, show p-values?
+#' @param pad Numerical, padding above and bellow rows.
+#' @param method An integer indicating methods for continuous variables.
+#' 1 Reports means and standard deviations.
+#' 2 Reports medians and interquartile ranges.
+#' @param ... Additional arguments passed to \code{\link[gtsummary]{tbl_summary}}.
+#' @details Function \code{cross_tbl} is a relatively simple wrapper to function \code{\link[gtsummary]{tbl_summary}}. It constructs contingency tables and can also be used to report a table with descriptives for all variables stratified by one of the variables. Please see examples to see how to list variables. If data is labelled, the label of the stratifying variable is used as part of the header.
+#' @return A huxtable with descriptive statistics stratified by levels of the outcome.
+#' @seealso \code{\link[gtsummary]{tbl_summary}}
+#' @examples
+#' require(dplyr, quietly = TRUE)
+#'
+#' #' data(Oncho)
+#'
+#' ## A two by two contingency table:
+#' Oncho %>%
+#'   select(mf, area) %>%
+#'   cross_tbl(by = "mf", bold = TRUE) %>%
+#'   theme_pubh(2)
+#'
+#' ## Reporting prevalence:
+#' Oncho %>%
+#'   select(mf, area) %>%
+#'   cross_tbl(by = "area", bold = TRUE) %>%
+#'   theme_pubh(2)
+#'
+#' ## Descriptive statistics for all variables in the \code{Oncho} data set except \code{id}.
+#' Oncho %>%
+#'   select(-id) %>%
+#'   cross_tbl(by = "mf", bold = TRUE) %>%
+#'   theme_pubh(2)
+#' @export
+cross_tbl <- function(data, by, head_label = " ",
+                      bold = TRUE, show_total = TRUE, p_val = FALSE,
+                      pad = 3, method = 2, ...) {
+  if (method == 1) {
+    tbl <- data %>%
+      gtsummary::tbl_summary(
+        by = tidyselect::all_of(by),
+        statistic = list(all_continuous() ~ "{mean} ({sd})"),
+        ...
+      ) %>%
+      gtsummary::modify_spanning_header(all_stat_cols() ~ paste0(
+        "**",
+        sjlabelled::get_label(data[[by]]),
+        "**"
+      ))
+  } else {
+    tbl <- data %>%
+      gtsummary::tbl_summary(
+        by = tidyselect::all_of(by),
+        ...
+      ) %>%
+      gtsummary::modify_spanning_header(all_stat_cols() ~ paste0(
+        "**",
+        sjlabelled::get_label(data[[by]]),
+        "**"
+      ))
+  }
+
+  if (show_total == FALSE) {
+    tbl <- tbl
+  } else {
+    tbl <- tbl %>%
+      gtsummary::add_overall(last = TRUE)
+  }
+
+  tbl <- tbl %>%
+    gtsummary::modify_header(label ~ head_label) %>%
+    gtsummary::modify_footnote(everything() ~ NA)
+
+  if (bold == FALSE) {
+    tbl <- tbl
+  } else {
+    tbl <- tbl %>% gtsummary::bold_labels()
+  }
+
+  if (p_val == TRUE) {
+    tbl <- tbl %>% gtsummary::add_p()
+  } else {
+    tbl <- tbl
+  }
+
+  tbl <- tbl %>%
+    gtsummary::as_hux_table() %>%
+    huxtable::set_align(everywhere, -1, "right") %>%
+    huxtable::set_top_padding(pad) %>%
+    huxtable::set_bottom_padding(pad) %>%
+    huxtable::set_align(1, everywhere, "center")
+
+  tbl
+}
+
 #' Descriptive statistics for continuous variables.
 #'
 #' \code{estat} calculates descriptives of numerical variables.
@@ -247,25 +344,25 @@ cross_tab <- function(object = NULL, formula = NULL, data = NULL,
 #' @examples
 #' data(kfm, package = "ISwR")
 #' require(sjlabelled, quietly = TRUE)
-#' kfm = kfm %>%
-#' var_labels(
-#'   dl.milk = 'Breast-milk intake (dl/day)',
-#'   sex = 'Sex',
-#'   weight = 'Child weight (kg)',
-#'   ml.suppl = 'Milk substitute (ml/day)',
-#'   mat.weight = 'Maternal weight (kg)',
-#'   mat.height = 'Maternal height (cm)'
-#'  )
+#' kfm <- kfm %>%
+#'   var_labels(
+#'     dl.milk = "Breast-milk intake (dl/day)",
+#'     sex = "Sex",
+#'     weight = "Child weight (kg)",
+#'     ml.suppl = "Milk substitute (ml/day)",
+#'     mat.weight = "Maternal weight (kg)",
+#'     mat.height = "Maternal height (cm)"
+#'   )
 #'
 #' kfm %>%
-#'   estat(~ dl.milk)
+#'   estat(~dl.milk)
 #'
-#' estat(~ dl.milk|sex, data = kfm)
+#' estat(~ dl.milk | sex, data = kfm)
 #'
 #' kfm %>%
-#'   estat(~ weight|sex)
-estat <- function (object = NULL, formula = NULL, data = NULL, digits = 2, label = NULL)
-{
+#'   estat(~ weight | sex)
+#' @export
+estat <- function(object = NULL, formula = NULL, data = NULL, digits = 2, label = NULL) {
   if (inherits(object, "formula")) {
     formula <- object
     object <- NULL
@@ -277,9 +374,10 @@ estat <- function (object = NULL, formula = NULL, data = NULL, digits = 2, label
   vars <- all.vars(formula)
   y <- vars[1]
   outcome <- data[[y]]
-  if (!is.numeric(outcome))
+  if (!is.numeric(outcome)) {
     stop(y, " must be a numerical variable")
-  if (is.null(sjlabelled::get_label(outcome)) == FALSE & is.null(label)){
+  }
+  if (is.null(sjlabelled::get_label(outcome)) == FALSE & is.null(label)) {
     lab <- sjlabelled::get_label(outcome)
   } else {
     lab <- ifelse(is.null(label), y, label)
@@ -291,23 +389,26 @@ estat <- function (object = NULL, formula = NULL, data = NULL, digits = 2, label
     res <- data.frame(lab, res)
     names(res)[1] <- ""
     res
-  }
-  else {
+  } else {
     x <- vars[2]
     exposure <- data[[x]]
-    if (!is.factor(exposure))
+    if (!is.factor(exposure)) {
       stop(x, " must be a factor")
+    }
     lev <- levels(exposure)
     nl <- length(lev)
     res <- numeric(nl * 7)
     dim(res) <- c(nl, 7)
     for (i in 1:nl) {
       res[i, ] <- as.numeric(stats_quotes(y,
-                                          data2 = subset(data, exposure == lev[i])))
+        data2 = subset(data, exposure == lev[i])
+      ))
     }
     res <- as.data.frame(res)
-    names(res) <- c("N", "Min.", "Max.", "Mean", "Median",
-                    "SD", "CV")
+    names(res) <- c(
+      "N", "Min.", "Max.", "Mean", "Median",
+      "SD", "CV"
+    )
     res <- round(res, digits = digits)
     res <- data.frame(var = lev, res)
     names(res)[1] <- x
@@ -316,7 +417,8 @@ estat <- function (object = NULL, formula = NULL, data = NULL, digits = 2, label
     res <- data.frame(var, res)
     names(res)[1] <- ""
     names(res)[2] <- ifelse(is.null(sjlabelled::get_label(exposure)) == FALSE,
-                            sjlabelled::get_label(exposure), x)
+      sjlabelled::get_label(exposure), x
+    )
     res
   }
 }
